@@ -11,6 +11,7 @@ from cloud_governance.aws.tag_non_cluster.run_tag_non_cluster_resources import t
 from cloud_governance.aws.tag_user.run_tag_iam_user import tag_iam_user, run_validate_iam_user_tags
 from cloud_governance.aws.zombie_cluster.run_zombie_cluster_resources import zombie_cluster_resource
 from cloud_governance.gitleaks.gitleaks import GitLeaks
+from cloud_governance.ibm.ibm_operations.tag_resources import TagResources
 from cloud_governance.main.es_uploader import ESUploader
 from cloud_governance.common.clouds.aws.s3.s3_operations import S3Operations
 from cloud_governance.aws.zombie_cluster.validate_zombies import ValidateZombies
@@ -251,6 +252,12 @@ def main():
     if is_zombie_non_cluster_polices_runner:
         zombie_non_cluster_polices_runner = ZombieNonClusterPolicies()
 
+    tag_ibm_classic_infrastructure_policies = ['tag_baremetal', 'tag_vm']
+    tag_ibm_classic_infrastructure_runner = None
+    is_tag_ibm_classic_infrastructure_runner = policy in tag_ibm_classic_infrastructure_policies
+    if is_tag_ibm_classic_infrastructure_runner:
+        tag_ibm_classic_infrastructure_runner = TagResources()
+
     cost_explorer_policies = ['cost_explorer', 'cost_over_usage']
     cost_explorer_policies_runner = None
     is_cost_explorer_policies_runner = policy in cost_explorer_policies
@@ -261,6 +268,9 @@ def main():
     def run_zombie_non_cluster_polices_runner():
         zombie_non_cluster_polices_runner.run()
 
+    def run_tag_ibm_classic_infrastructure_runner():
+        tag_ibm_classic_infrastructure_runner.run()
+
     @logger_time_stamp
     def run_cost_explorer_policies_runner():
         cost_explorer_policies_runner.run()
@@ -283,6 +293,8 @@ def main():
     # 2. POLICY
     elif is_zombie_non_cluster_polices_runner:
         run_zombie_non_cluster_polices_runner()
+    elif is_tag_ibm_classic_infrastructure_runner:
+        run_tag_ibm_classic_infrastructure_runner()
     elif is_cost_explorer_policies_runner:
         run_cost_explorer_policies_runner()
     else:
